package com.ruoyi.web.controller.gw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.GwArticle;
import com.ruoyi.system.service.IGwArticleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 官网文章列表Controller
 *
 * @author libao
 * @date 2024-04-28
 */
@RestController
@RequestMapping("/system/article")
public class GwArticleController extends BaseController
{
    @Autowired
    private IGwArticleService gwArticleService;

    /**
     * 查询官网文章列表列表
     */
    @PreAuthorize("@ss.hasPermi('system:article:list')")
    @GetMapping("/list")
    public TableDataInfo list(GwArticle gwArticle)
    {
        startPage();
        List<GwArticle> list = gwArticleService.selectGwArticleList(gwArticle);
        return getDataTable(list);
    }

    /**
     * 导出官网文章列表列表
     */
    @PreAuthorize("@ss.hasPermi('system:article:export')")
    @Log(title = "官网文章列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GwArticle gwArticle)
    {
        List<GwArticle> list = gwArticleService.selectGwArticleList(gwArticle);
        ExcelUtil<GwArticle> util = new ExcelUtil<GwArticle>(GwArticle.class);
        util.exportExcel(response, list, "官网文章列表数据");
    }

    /**
     * 获取官网文章列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:article:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gwArticleService.selectGwArticleById(id));
    }

    /**
     * 新增官网文章列表
     */
    @PreAuthorize("@ss.hasPermi('system:article:add')")
    @Log(title = "官网文章列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GwArticle gwArticle)
    {
        return toAjax(gwArticleService.insertGwArticle(gwArticle));
    }

    /**
     * 修改官网文章列表
     */
    @PreAuthorize("@ss.hasPermi('system:article:edit')")
    @Log(title = "官网文章列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GwArticle gwArticle)
    {
        return toAjax(gwArticleService.updateGwArticle(gwArticle));
    }

    /**
     * 删除官网文章列表
     */
    @PreAuthorize("@ss.hasPermi('system:article:remove')")
    @Log(title = "官网文章列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gwArticleService.deleteGwArticleByIds(ids));
    }
}
