package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.GwCategoryMapper;
import com.ruoyi.system.domain.GwCategory;
import com.ruoyi.system.service.IGwCategoryService;

/**
 * 文章分类Service业务层处理
 * 
 * @author lb
 * @date 2024-04-28
 */
@Service
public class GwCategoryServiceImpl implements IGwCategoryService 
{
    @Autowired
    private GwCategoryMapper gwCategoryMapper;

    /**
     * 查询文章分类
     * 
     * @param id 文章分类主键
     * @return 文章分类
     */
    @Override
    public GwCategory selectGwCategoryById(Long id)
    {
        return gwCategoryMapper.selectGwCategoryById(id);
    }

    /**
     * 查询文章分类列表
     * 
     * @param gwCategory 文章分类
     * @return 文章分类
     */
    @Override
    public List<GwCategory> selectGwCategoryList(GwCategory gwCategory)
    {
        return gwCategoryMapper.selectGwCategoryList(gwCategory);
    }

    /**
     * 新增文章分类
     * 
     * @param gwCategory 文章分类
     * @return 结果
     */
    @Override
    public int insertGwCategory(GwCategory gwCategory)
    {
        gwCategory.setCreateTime(DateUtils.getNowDate());
        return gwCategoryMapper.insertGwCategory(gwCategory);
    }

    /**
     * 修改文章分类
     * 
     * @param gwCategory 文章分类
     * @return 结果
     */
    @Override
    public int updateGwCategory(GwCategory gwCategory)
    {
        gwCategory.setUpdateTime(DateUtils.getNowDate());
        return gwCategoryMapper.updateGwCategory(gwCategory);
    }

    /**
     * 批量删除文章分类
     * 
     * @param ids 需要删除的文章分类主键
     * @return 结果
     */
    @Override
    public int deleteGwCategoryByIds(Long[] ids)
    {
        return gwCategoryMapper.deleteGwCategoryByIds(ids);
    }

    /**
     * 删除文章分类信息
     * 
     * @param id 文章分类主键
     * @return 结果
     */
    @Override
    public int deleteGwCategoryById(Long id)
    {
        return gwCategoryMapper.deleteGwCategoryById(id);
    }
}
